@@ -305,3 +305,17 @@ test_that("fb_team_player_stats() works", {
   expect_error(fb_team_player_stats(team_urls= "https://fbref.com/en/squads/d6a369a2/Fleetwood-Town-Stats", stat_type= 'stangard'))
 
 })
+
+
+test_that("fb_team_match_log_stats() works", {
+  testthat::skip_on_cran()
+  liv_passing_log <- fb_team_match_log_stats(team_url= "https://fbref.com/en/squads/822bd0ba/Liverpool-Stats", stat_type= 'passing')
+  expect_type(liv_passing_log, "list")
+  expect_false(nrow(liv_passing_log) == 0)
+
+  # this should error because the stat type isn't available
+  expect_error(fb_team_match_log_stats(team_url = "https://fbref.com/en/squads/d6a369a2/Fleetwood-Town-Stats", stat_type= 'keeper_adv'))
+  # this should error because the spelling of the stat type is incorrect
+  expect_error(fb_team_player_stats(team_urls= "https://fbref.com/en/squads/d6a369a2/Fleetwood-Town-Stats", stat_type= 'shooooooting'))
+
+})
